@@ -54,7 +54,7 @@ class SimplePOP3Retriever(POP3RetrieverBase, POP3initMixIn):
     '''Retriever class for single-user POP3 mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -79,15 +79,15 @@ class SimplePOP3Retriever(POP3RetrieverBase, POP3initMixIn):
 
     def showconf(self):
         self.log.trace()
-        self.log.info('SimplePOP3Retriever(%s)' % self._confstring()
-                      + os.linesep)
+        self.log.info('SimplePOP3Retriever(%s)' % self._confstring() 
+            + os.linesep)
 
 #######################################
 class SimplePOP3SSLRetriever(POP3RetrieverBase, POP3SSLinitMixIn):
     '''Retriever class for single-user POP3-over-SSL mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -115,15 +115,15 @@ class SimplePOP3SSLRetriever(POP3RetrieverBase, POP3SSLinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('SimplePOP3SSLRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class BrokenUIDLPOP3RetrieverBase(POP3RetrieverBase):
-    '''Retriever base class for single-user POP3 mailboxes on servers that do
-    not properly assign unique IDs to messages.  Since with these broken servers
-    we cannot rely on UIDL, we have to use message numbers, which are unique
-    within a POP3 session, but which change across sessions.  This class
-    therefore can not be used to leave old mail on the server and download only
+    '''Retriever base class for single-user POP3 mailboxes on servers that do 
+    not properly assign unique IDs to messages.  Since with these broken servers 
+    we cannot rely on UIDL, we have to use message numbers, which are unique 
+    within a POP3 session, but which change across sessions.  This class 
+    therefore can not be used to leave old mail on the server and download only 
     new mail.
     '''
     received_from = None
@@ -134,7 +134,7 @@ class BrokenUIDLPOP3RetrieverBase(POP3RetrieverBase):
         duplicated IDs are always treated as new messages.'''
         self.log.trace()
 
-    def write_oldmailfile(self, unused, **kwargs):
+    def write_oldmailfile(self, **kwargs):
         '''Short-circuit writing the oldmail file.'''
         self.log.trace()
 
@@ -142,14 +142,13 @@ class BrokenUIDLPOP3RetrieverBase(POP3RetrieverBase):
         '''Don't rely on UIDL; instead, use just the message number.'''
         self.log.trace()
         try:
-            (response, msglist, octets) = self.conn.list()
+            response, msglist, octets = self.conn.list()
             for line in msglist:
                 msgnum = int(line.split()[0])
                 msgsize = int(line.split()[1])
                 self.msgnum_by_msgid[msgnum] = msgnum
                 self.msgid_by_msgnum[msgnum] = msgnum
                 self.msgsizes[msgnum] = msgsize
-            self.sorted_msgnum_msgid = sorted(self.msgid_by_msgnum.items())
         except poplib.error_proto, o:
             raise getmailOperationError('POP error (%s)' % o)
         self.gotmsglist = True
@@ -159,7 +158,7 @@ class BrokenUIDLPOP3Retriever(BrokenUIDLPOP3RetrieverBase, POP3initMixIn):
     '''For broken POP3 servers without SSL.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -182,14 +181,14 @@ class BrokenUIDLPOP3Retriever(BrokenUIDLPOP3RetrieverBase, POP3initMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('BrokenUIDLPOP3Retriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class BrokenUIDLPOP3SSLRetriever(BrokenUIDLPOP3RetrieverBase, POP3SSLinitMixIn):
     '''For broken POP3 servers with SSL.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -214,14 +213,14 @@ class BrokenUIDLPOP3SSLRetriever(BrokenUIDLPOP3RetrieverBase, POP3SSLinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('BrokenUIDLPOP3SSLRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class MultidropPOP3Retriever(MultidropPOP3RetrieverBase, POP3initMixIn):
     '''Retriever class for multi-drop POP3 mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -247,14 +246,14 @@ class MultidropPOP3Retriever(MultidropPOP3RetrieverBase, POP3initMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('MultidropPOP3Retriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class MultidropPOP3SSLRetriever(MultidropPOP3RetrieverBase, POP3SSLinitMixIn):
     '''Retriever class for multi-drop POP3-over-SSL mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -282,7 +281,7 @@ class MultidropPOP3SSLRetriever(MultidropPOP3RetrieverBase, POP3SSLinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('MultidropPOP3SSLRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class MultidropSDPSRetriever(SimplePOP3Retriever, POP3initMixIn):
@@ -296,7 +295,7 @@ class MultidropSDPSRetriever(SimplePOP3Retriever, POP3initMixIn):
     Support originally requested by Paul Clifford for getmail v.2/3.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -323,7 +322,7 @@ class MultidropSDPSRetriever(SimplePOP3Retriever, POP3initMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('MultidropSDPSRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
     def _getmsgbyid(self, msgid):
         self.log.trace()
@@ -334,9 +333,8 @@ class MultidropSDPSRetriever(SimplePOP3Retriever, POP3initMixIn):
             msgnum = self._getmsgnumbyid(msgid)
             resp, lines, octets = self.conn._longcmd('*ENV %i' % msgnum)
         except poplib.error_proto, o:
-            raise getmailConfigurationError(
-                'server does not support *ENV (%s)' % o
-            )
+            raise getmailConfigurationError('server does not support *ENV (%s)'
+                % o)
         if len(lines) < 4:
             raise getmailOperationError('short *ENV response (%s)' % lines)
         msg.sender = lines[2]
@@ -348,7 +346,7 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
     '''Retriever class for single-user IMAPv4 mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -356,14 +354,11 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfUnicode(name='mailboxes', required=False,
-                           default="('INBOX', )", allow_specials=('ALL',)),
-        ConfBool(name='use_peek', required=False, default=True),
+        ConfTupleOfStrings(name='mailboxes', required=False, default="('INBOX', )"),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
-        ConfBool(name='use_kerberos', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4'
@@ -380,14 +375,14 @@ class SimpleIMAPRetriever(IMAPRetrieverBase, IMAPinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('SimpleIMAPRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
     '''Retriever class for single-user IMAPv4-over-SSL mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         # socket.ssl() and socket timeouts are incompatible in Python 2.3
@@ -396,16 +391,13 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfUnicode(name='mailboxes', required=False,
-                           default="('INBOX', )", allow_specials=('ALL',)),
-        ConfBool(name='use_peek', required=False, default=True),
+        ConfTupleOfStrings(name='mailboxes', required=False, default="('INBOX', )"),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
-        ConfBool(name='use_kerberos', required=False, default=False),
     )
     received_from = None
     received_with = 'IMAP4-SSL'
@@ -422,14 +414,14 @@ class SimpleIMAPSSLRetriever(IMAPRetrieverBase, IMAPSSLinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('SimpleIMAPSSLRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
     '''Retriever class for multi-drop IMAPv4 mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         ConfInt(name='timeout', required=False, default=180),
@@ -437,14 +429,11 @@ class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
         ConfInt(name='port', required=False, default=imaplib.IMAP4_PORT),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfUnicode(name='mailboxes', required=False,
-                           default="('INBOX', )", allow_specials=('ALL',)),
-        ConfBool(name='use_peek', required=False, default=True),
+        ConfTupleOfStrings(name='mailboxes', required=False, default="('INBOX', )"),
         ConfString(name='move_on_delete', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
-        ConfBool(name='use_kerberos', required=False, default=False),
         ConfString(name='envelope_recipient'),
     )
     received_from = None
@@ -462,32 +451,29 @@ class MultidropIMAPRetriever(MultidropIMAPRetrieverBase, IMAPinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('MultidropIMAPRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
 
 #######################################
 class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
     '''Retriever class for multi-drop IMAPv4-over-SSL mailboxes.
     '''
     _confitems = (
-        ConfInstance(name='configparser', required=False),
+        ConfInstance(name='configparser'),
         ConfDirectory(name='getmaildir', required=False, default='~/.getmail/'),
 
         # socket.ssl() and socket timeouts are incompatible in Python 2.3
         #ConfInt(name='timeout', required=False, default=180),
         ConfString(name='server'),
-        ConfInt(name='port', required=False, default=imaplib.IMAP4_SSL_PORT),
+        ConfInt(name='port', required=False, default=110),
         ConfString(name='username'),
         ConfPassword(name='password', required=False, default=None),
-        ConfTupleOfUnicode(name='mailboxes', required=False,
-                           default="('INBOX', )", allow_specials=('ALL',)),
-        ConfBool(name='use_peek', required=False, default=True),
+        ConfTupleOfStrings(name='mailboxes', required=False, default="('INBOX', )"),
         ConfString(name='move_on_delete', required=False, default=None),
         ConfFile(name='keyfile', required=False, default=None),
         ConfFile(name='certfile', required=False, default=None),
         # imaplib.IMAP4.login_cram_md5() requires the (unimplemented)
         # .authenticate(), so we can't do this yet (?).
         ConfBool(name='use_cram_md5', required=False, default=False),
-        ConfBool(name='use_kerberos', required=False, default=False),
         ConfString(name='envelope_recipient'),
     )
     received_from = None
@@ -505,4 +491,4 @@ class MultidropIMAPSSLRetriever(MultidropIMAPRetrieverBase, IMAPSSLinitMixIn):
     def showconf(self):
         self.log.trace()
         self.log.info('MultidropIMAPSSLRetriever(%s)' % self._confstring()
-                      + os.linesep)
+            + os.linesep)
